internal/context

Values

pub fn add_entry(key: String, value: a) -> Nil

Stores the value as referenced by key only if no value is already present.

This returns the stored value.

pub fn erase(key: String) -> Bool

Erase the value referenced by key.

Returns True if there was a value, False otherwise.

pub fn get_orelse(key key: String, or default: a) -> a

Retrieve the value referenced by key or default if not present.

pub fn shared_add_entry(key: String, value: a) -> Nil

Adds a value as a share property to Inertia context

pub fn shared_get_all() -> dict.Dict(String, String)
pub fn shared_get_orelse(key key: String, or default: a) -> a

Gets a value of share property from Inertia context, or return a default value if the property does not exists

Search Document