internal/context

Values

pub fn add_entry(key: String, value: a) -> Nil

Stores the value as referenced by key only if no value is already present.

This returns the stored value.

pub fn erase(key: String) -> Bool

Erase the value referenced by key.

Returns True if there was a value, False otherwise.

pub fn get_orelse(key key: String, or default: a) -> a

Retrieve the value referenced by key or default if not present.

Search Document